@@ -3,6 +3,19 @@
 
 #if defined(OPEN_MPI)
 
+/*
+ * The hackery below redefines the actuall calls to 'MPI_Init()' and
+ * 'MPI_Init_thread()' in order to preload the main MPI dynamic
+ * library with appropriate flags to 'dlopen()' ensuring global
+ * availability of library symbols.
+ */
+
+#if !defined(OPENMPI_DLOPEN_LIBMPI) && defined(OMPI_MAJOR_VERSION)
+#if OMPI_MAJOR_VERSION >= 3 && OMPI_MAJOR_VERSION < 10
+#define OPENMPI_DLOPEN_LIBMPI 0
+#endif
+#endif
+
 #ifndef OPENMPI_DLOPEN_LIBMPI
 #define OPENMPI_DLOPEN_LIBMPI 1
 #endif
@@ -93,26 +106,48 @@ static void OPENMPI_dlopen_libmpi(void)
 {
   void *handle = 0;
   int mode = RTLD_NOW | RTLD_GLOBAL;
+#if defined(__APPLE__)
+  /* macOS */
   #ifdef RTLD_NOLOAD
   mode |= RTLD_NOLOAD;
   #endif
-#if defined(__CYGWIN__)
-  if (!handle) handle = dlopen("cygmpi.dll", mode);
-  if (!handle) handle = dlopen("mpi.dll",    mode);
-#elif defined(__APPLE__)
-  /* Mac OS X */
-  if (!handle) handle = dlopen("libmpi.3.dylib", mode);
-  if (!handle) handle = dlopen("libmpi.2.dylib", mode);
+  #if defined(OMPI_MAJOR_VERSION)
+  #if OMPI_MAJOR_VERSION == 3
+  if (!handle) handle = dlopen("libmpi.40.dylib", mode);
+  #elif OMPI_MAJOR_VERSION == 2
+  if (!handle) handle = dlopen("libmpi.20.dylib", mode);
+  #elif OMPI_MAJOR_VERSION == 1 && OMPI_MINOR_VERSION >= 10
+  if (!handle) handle = dlopen("libmpi.12.dylib", mode);
+  #elif OMPI_MAJOR_VERSION == 1 && OMPI_MINOR_VERSION >= 6
   if (!handle) handle = dlopen("libmpi.1.dylib", mode);
+  #elif OMPI_MAJOR_VERSION == 1
   if (!handle) handle = dlopen("libmpi.0.dylib", mode);
-  if (!handle) handle = dlopen("libmpi.dylib",   mode);
+  #endif
+  #endif
+  if (!handle) handle = dlopen("libmpi.dylib", mode);
 #else
   /* GNU/Linux and others */
-  if (!handle) handle = dlopen("libmpi.so.3", mode);
-  if (!handle) handle = dlopen("libmpi.so.2", mode);
+  #ifdef RTLD_NOLOAD
+  mode |= RTLD_NOLOAD;
+  #endif
+  #if defined(OMPI_MAJOR_VERSION)
+  #if OMPI_MAJOR_VERSION >= 10 /* IBM Spectrum MPI */
+  if (!handle) handle = dlopen("libmpi_ibm.so.2", mode);
+  if (!handle) handle = dlopen("libmpi_ibm.so.1", mode);
+  if (!handle) handle = dlopen("libmpi_ibm.so", mode);
+  #elif OMPI_MAJOR_VERSION == 3
+  if (!handle) handle = dlopen("libmpi.so.40", mode);
+  #elif OMPI_MAJOR_VERSION == 2
+  if (!handle) handle = dlopen("libmpi.so.20", mode);
+  #elif OMPI_MAJOR_VERSION == 1 && OMPI_MINOR_VERSION >= 10
+  if (!handle) handle = dlopen("libmpi.so.12", mode);
+  #elif OMPI_MAJOR_VERSION == 1 && OMPI_MINOR_VERSION >= 6
   if (!handle) handle = dlopen("libmpi.so.1", mode);
+  #elif OMPI_MAJOR_VERSION == 1
   if (!handle) handle = dlopen("libmpi.so.0", mode);
-  if (!handle) handle = dlopen("libmpi.so",   mode);
+  #endif
+  #endif
+  if (!handle) handle = dlopen("libmpi.so", mode);
 #endif
 }
 
