@@ -123,6 +123,30 @@ class BaseTestDA(object):
         vg2 = self.da.createGlobalVec()
         self.da.localToGlobal(vl2,vg2)
 
+    def testGetVec(self):
+        vg = self.da.getGlobalVec()
+        vl = self.da.getLocalVec()
+        try:
+            vg.set(1.0)
+            self.assertEqual(vg.max()[1], 1.0)
+            self.assertEqual(vg.min()[1], 1.0)
+            self.da.globalToLocal(vg,vl)
+            self.assertEqual(vl.max()[1], 1.0)
+            self.assertTrue (vl.min()[1] in (1.0, 0.0))
+            vl.set(2.0)
+            NONE = PETSc.DM.BoundaryType.NONE
+            s = self.da.stencil_width
+            btype = self.da.boundary_type
+            psize = self.da.proc_sizes
+            for b, p in zip(btype, psize):
+                if b != NONE and p == 1: return
+            self.da.localToGlobal(vl,vg)
+            self.assertEqual(vg.max()[1], 2.0)
+            self.assertTrue (vg.min()[1] in (2.0, 0.0))
+        finally:
+            self.da.restoreGlobalVec(vg)
+            self.da.restoreLocalVec(vl)
+
     def testGetOther(self):
         ao = self.da.getAO()
         lgmap = self.da.getLGMap()
@@ -225,14 +249,17 @@ class TestDA_2D_W2_N2(TestDA_2D):
     DOF = 2
     SWIDTH = 2
 class TestDA_2D_PXY(TestDA_2D):
+    SIZES = [13*SCALE,17*SCALE]
     DOF = 2
     SWIDTH = 5
     BOUNDARY = (PERIODIC,)*2
 class TestDA_2D_GXY(TestDA_2D):
+    SIZES = [13*SCALE,17*SCALE]
     DOF = 2
     SWIDTH = 5
     BOUNDARY = (GHOSTED,)*2
 class TestDA_2D_TXY(TestDA_2D):
+    SIZES = [13*SCALE,17*SCALE]
     DOF = 2
     SWIDTH = 5
     BOUNDARY = (TWIST,)*2
@@ -250,14 +277,17 @@ class TestDA_3D_W2_N2(TestDA_3D):
     DOF = 2
     SWIDTH = 2
 class TestDA_3D_PXYZ(TestDA_3D):
+    SIZES = [11*SCALE,13*SCALE,17*SCALE]
     DOF = 2
     SWIDTH = 3
     BOUNDARY = (PERIODIC,)*3
 class TestDA_3D_GXYZ(TestDA_3D):
+    SIZES = [11*SCALE,13*SCALE,17*SCALE]
     DOF = 2
     SWIDTH = 3
     BOUNDARY = (GHOSTED,)*3
 class TestDA_3D_TXYZ(TestDA_3D):
+    SIZES = [11*SCALE,13*SCALE,17*SCALE]
     DOF = 2
     SWIDTH = 3
     BOUNDARY = (TWIST,)*3
